@@ -1,4 +1,7 @@
-import cPickle as pickle
+from __future__ import unicode_literals
+from __future__ import print_function
+
+import base64
 
 from django.db import models
 from django.db.models.query import QuerySet
@@ -6,8 +9,10 @@ from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import get_language, activate
+from django.utils.encoding import python_2_unicode_compatible
+from django.utils.six.moves import cPickle as pickle  # pylint: disable-msg=F
 
-from django.contrib.auth.models import User
+from .compat import AUTH_USER_MODEL
 
 from notification import backends
 
@@ -28,27 +33,28 @@ def create_notice_type(label, display, description, **kwargs):
     NoticeType.create(label, display, description, **kwargs)
 
 
+@python_2_unicode_compatible
 class NoticeType(models.Model):
-    
+
     label = models.CharField(_("label"), max_length=40)
     display = models.CharField(_("display"), max_length=50)
     description = models.CharField(_("description"), max_length=100)
-    
+
     # by default only on for media with sensitivity less than or equal to this number
     default = models.IntegerField(_("default"))
-    
-    def __unicode__(self):
+
+    def __str__(self):
         return self.label
-    
+
     class Meta:
         verbose_name = _("notice type")
         verbose_name_plural = _("notice types")
-    
+
     @classmethod
     def create(cls, label, display, description, default=2, verbosity=1):
         """
         Creates a new NoticeType.
-        
+
         This is intended to be used by other apps as a post_syncdb manangement step.
         """
         try:
@@ -66,11 +72,11 @@ class NoticeType(models.Model):
             if updated:
                 notice_type.save()
                 if verbosity > 1:
-                    print "Updated %s NoticeType" % label
+                    print("Updated %s NoticeType" % label)
         except cls.DoesNotExist:
             cls(label=label, display=display, description=description, default=default).save()
             if verbosity > 1:
-                print "Created %s NoticeType" % label
+                print("Created %s NoticeType" % label)
 
 
 class NoticeSetting(models.Model):
@@ -78,17 +84,17 @@ class NoticeSetting(models.Model):
     Indicates, for a given user, whether to send notifications
     of a given type to a given medium.
     """
-    
-    user = models.ForeignKey(User, verbose_name=_("user"))
+
+    user = models.ForeignKey(AUTH_USER_MODEL, verbose_name=_("user"))
     notice_type = models.ForeignKey(NoticeType, verbose_name=_("notice type"))
     medium = models.CharField(_("medium"), max_length=1, choices=NOTICE_MEDIA)
     send = models.BooleanField(_("send"))
-    
+
     class Meta:
         verbose_name = _("notice setting")
         verbose_name_plural = _("notice settings")
         unique_together = ("user", "notice_type", "medium")
-    
+
     @classmethod
     def for_user(cls, user, notice_type, medium):
         try:
@@ -130,9 +136,9 @@ def get_notification_language(user):
 def send_now(users, label, extra_context=None, sender=None):
     """
     Creates a new notice.
-    
+
     This is intended to be how other apps create new notices.
-    
+
     notification.send(user, "friends_invite_sent", {
         "spam": "eggs",
         "foo": "bar",
@@ -141,11 +147,11 @@ def send_now(users, label, extra_context=None, sender=None):
     sent = False
     if extra_context is None:
         extra_context = {}
-    
+
     notice_type = NoticeType.objects.get(label=label)
-    
+
     current_language = get_language()
-    
+
     for user in users:
         # get user language for user from language store defined in
         # NOTIFICATION_LANGUAGE_MODULE setting
@@ -153,16 +159,16 @@ def send_now(users, label, extra_context=None, sender=None):
             language = get_notification_language(user)
         except LanguageStoreNotAvailable:
             language = None
-        
+
         if language is not None:
             # activate the user's language
             activate(language)
-        
+
         for backend in NOTIFICATION_BACKENDS.values():
             if backend.can_send(user, notice_type):
                 backend.deliver(user, sender, notice_type, extra_context)
                 sent = True
-    
+
     # reset environment to original language
     activate(current_language)
     return sent
@@ -204,4 +210,4 @@ def queue(users, label, extra_context=None, sender=None):
     notices = []
     for user in users:
         notices.append((user, label, extra_context, sender))
-    NoticeQueueBatch(pickled_data=pickle.dumps(notices).encode("base64")).save()
+    NoticeQueueBatch(pickled_data=base64.b64encode(pickle.dumps(notices))).save()
